"use strict";

exports.__esModule = true;
exports.default = buildOptions;

var _defaultOptions = require("./defaultOptions");

var _defaultOptions2 = _interopRequireDefault(_defaultOptions);

var _util = require("./util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Build a valid options object that can be used to pass
 * options to other presets and/or plugins.
 *
 * @param {object} _config
 * @returns {{async:object, config:object, env:object, resolver:object}}
 */
function buildOptions() {
    var _config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var config = Object.assign(_defaultOptions2.default, _config);
    var asyncOptions = void 0,
        envOptions = void 0,
        resolverOptions = void 0;

    if (typeof config.stage !== "number") config.stage = -1;

    envOptions = {

        "debug": !!config.debug,
        "include": (0, _util.castArray)(config.include),
        "exclude": (0, _util.castArray)(config.exclude),
        "loose": !!config.loose,
        "modules": config.modules || _defaultOptions2.default.modules,
        "spec": !!config.spec,
        "targets": {
            "uglify": !!config.uglify
        },
        "useBuiltIns": !!config.useBuiltIns

    };

    if (!config.disableResolver) {

        resolverOptions = {

            "alias": config.alias || _defaultOptions2.default.alias,
            "cwd": config.cwd || _defaultOptions2.default.cwd,
            "extensions": (0, _util.castArray)(config.extensions, _defaultOptions2.default.extensions),
            "root": (0, _util.castArray)(config.root, _defaultOptions2.default.root)

        };
    }

    if (!config.regenerator) {

        (0, _util.listOnce)(envOptions.exclude, "transform-regenerator");
    }

    if (!config.asyncToGenerator) {

        (0, _util.listOnce)(envOptions.exclude, "transform-async-to-generator");
        var index = envOptions.exclude.indexOf("transform-async-to-module-method");

        if (index === -1) asyncOptions = {

            "module": config.asyncModule || _defaultOptions2.default.asyncModule,
            "method": config.asyncMethod || _defaultOptions2.default.asyncMethod

        };else if (index !== -1) envOptions.exclude.splice(index, 1);
    }

    if (!config.node) {

        var engines = (0, _util.getPackage)(config.cwd || _defaultOptions2.default.cwd).engines;

        config.node = engines && engines.node ? (0, _util.majorSemver)(String(engines.node)) : _defaultOptions2.default.defaultNodeVersion;
    }

    if (typeof config.node === "string") {

        config.node = config.node.includes(".") ? parseFloat(config.node) : parseInt(config.node, 10);
    }

    _util.targets.forEach(function (target) {

        if (!config.hasOwnProperty(target)) return 0;
        envOptions.targets[target] = config[target];
    });

    return {
        async: asyncOptions,
        config: config,
        env: envOptions,
        resolver: resolverOptions
    };
}