"use strict";

exports.__esModule = true;
exports.util = exports.preset = exports.defaultOptions = exports.buildOptions = undefined;
exports.default = preset;

var _buildOptions = require("./buildOptions");

var _buildOptions2 = _interopRequireDefault(_buildOptions);

var _defaultOptions = require("./defaultOptions");

var _defaultOptions2 = _interopRequireDefault(_defaultOptions);

var _util = require("./util");

var _util2 = _interopRequireDefault(_util);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Futago-za Ryuu's Babel preset generator.
 *
 * WARNING: This default method is only intended to be used by Babel.
 */

function preset(context, _config) {

    var options = (0, _buildOptions2.default)(_config);
    var config = options.config;
    var plugins = [];
    var presets = [];

    if (config.stage > -1 && config.stage < 4) {

        presets.push((0, _util.resolve)("babel-preset-stage-" + config.stage));
    }

    presets.push([(0, _util.resolve)("babel-preset-env"), options.env]);

    if (options.resolver) plugins.push([(0, _util.resolve)("babel-plugin-module-resolver"), options.resolver]);

    if (options.async) plugins.push([(0, _util.resolve)("babel-plugin-transform-async-to-module-method"), options.async]);

    return {
        shouldPrintComment: function shouldPrintComment(comment) {

            if (!config.removeEslintComments) return true;
            return comment.trim().startsWith("eslint", 0) === false;
        },


        "plugins": plugins,
        "presets": presets

    };
}

/**
 * Exports (e.g. `import * as preset from "babel-preset-futagozaryuu";`).
 */

exports.buildOptions = _buildOptions2.default;
exports.defaultOptions = _defaultOptions2.default;
exports.preset = preset;
exports.util = _util2.default;